@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/python3
 ## -*- coding: utf-8 -*-
 #
 #
@@ -25,6 +25,7 @@ import os
 import time
 import tarfile
 import logging
+import subprocess
 
 logger = logging.getLogger('mythbuntu-bare')
 hdlr = logging.FileHandler('/var/log/mythbuntu-bare-client.log')
