@@ -21,12 +21,11 @@
 ##################################################################################
 
 from MythbuntuControlCentre.plugin import MCCPlugin
-import gtk
 import time
 from threading import Thread
-import ConfigParser
+import configparser
 import sys
-import commands
+import subprocess
 import gobject
 import socket
 import os
@@ -56,33 +55,33 @@ class BareConsolePlugin(MCCPlugin):
         self.status_lastbackup_buffer = self.status_text_lastbackup.get_buffer()
         self.status_lastseen_buffer = self.status_text_lastseen.get_buffer()
         self.status_status_buffer = self.status_text_status.get_buffer()
-        self.config = ConfigParser.ConfigParser()
+        self.config = configparser.ConfigParser()
         if os.path.exists(CONFIGFILE):
           self.config.read(CONFIGFILE)
           try:
             self.changes['serverip'] = self.config.get("General", "serverip")
           except:
-            print "Cannot read serverip, setting default"
-            self.changes['serverip'] = commands.getoutput("/sbin/ifconfig").split("\n")[1].split()[1][5:]
+            print("Cannot read serverip, setting default")
+            self.changes['serverip'] = subprocess.getoutput("/sbin/ifconfig").split("\n")[1].split()[1][5:]
           try:
             self.changes['managed'] = self.config.get("General", "managed")
           except:
-            print "Cannot read managed state, setting default"
+            print("Cannot read managed state, setting default")
             self.changes['managed'] = "False"
           try:
             self.changes['revision'] = self.config.get("General", "revision")
           except:
-            print "Cannot read revision, setting default"
+            print("Cannot read revision, setting default")
             self.changes['revision'] = "0"
           try:
             self.changes['BackupLocation'] = self.config.get("Backup", "storagedir")
           except:
-            print "Cannot read Backup Location, setting default"
+            print("Cannot read Backup Location, setting default")
             self.changes['BackupLocation'] = "/var/lib/mythtv/bare"
           try:
             self.changes['backup_db'] = self.config.get("Backup", "db")
           except:
-            print "Cannot read db backup setting, setting default"
+            print("Cannot read db backup setting, setting default")
             self.changes['backup_db'] = "1"
           try:
             self.changes['backup_schedule'] = self.config.get("Backup", "schedule")
@@ -91,7 +90,7 @@ class BareConsolePlugin(MCCPlugin):
             self.changes['backup_schedule_minute'] = self.config.get("Backup", "minute")
             self.changes['backup_schedule_weekday'] = self.config.get("Backup", "weekday")
           except:
-            print "Cannot read schedule, setting default"
+            print("Cannot read schedule, setting default")
             self.changes['backup_schedule'] = "disabled"
             self.changes['backup_schedule_day'] = "*"
             self.changes['backup_schedule_hour'] = "0"
@@ -100,16 +99,16 @@ class BareConsolePlugin(MCCPlugin):
           try:
             self.changes['serverstoragedir'] = self.config.get("General", "serverstoragedir")
           except:
-            print "Cannot read server storage directory, setting default"
+            print("Cannot read server storage directory, setting default")
             self.changes['serverstoragedir'] = "/var/lib/mythtv/bare/"
           try:
             self.changes['serverport'] = self.config.get("General", "serverport")
           except:
-            print "Cannot read server port, setting default"
+            print("Cannot read server port, setting default")
             self.changes['serverport'] = self.PickUnusedPort()
         else:
-          print "Error: Config file not found. Setting defaults"
-          self.changes['serverip'] = commands.getoutput("/sbin/ifconfig").split("\n")[1].split()[1][5:]
+          print("Error: Config file not found. Setting defaults")
+          self.changes['serverip'] = subprocess.getoutput("/sbin/ifconfig").split("\n")[1].split()[1][5:]
           self.changes['managed'] = "False"
           self.changes['revision'] = "0"
           self.changes['BackupLocation'] = "/var/lib/mythtv/bare"
@@ -187,31 +186,31 @@ class BareConsolePlugin(MCCPlugin):
         """Determines what items have been modified on this plugin"""
         MCCPlugin.clearParentState(self)
         changes = False
-        print "*********************"
+        print("*********************")
         if not self.changes['serverip'] == self.serverip_entry.get_text():
           changes = True
-          print "serverip"
+          print("serverip")
         if not self.changes['serverport'] == self.port_entry.get_text():
           changes = True
-          print "serverport"
+          print("serverport")
         if not self.changes['managed'] == str(self.managed_radiobutton.get_active()) and not self.serverip_entry.get_text() == "127.0.0.1":
           changes = True
-          print "managed"
+          print("managed")
         if not self.changes['managed'] == str(self.managed_radiobutton.get_active()) and self.serverip_entry.get_text() == "127.0.0.1":
           self._markReconfigureUser('Error: Manager IP Address cannot be 127.0.0.1 in managed mode', False)
         if not self.changes['BackupLocation'] == self.backup_location.get_current_folder():
           changes = True
-          print "location"
+          print("location")
         if not self.changes['serverstoragedir'] == self.storage_location.get_current_folder():
           changes = True
-          print "serverstoragedir"
+          print("serverstoragedir")
         if self.db_backup_checkbutton.get_active() == True:
           self.db_checkbox = "1"
         else:
           self.db_checkbox = "0"
         if not self.changes['backup_db'] == self.db_checkbox:
           changes = True
-          print "db"
+          print("db")
         if self.schedule_daily_button.get_active():
           self.schedule = "daily"
         elif self.schedule_weekly_button.get_active():
@@ -222,21 +221,21 @@ class BareConsolePlugin(MCCPlugin):
           self.schedule = "disabled"
         if not self.changes['backup_schedule'] == self.schedule:
           changes = True
-          print "schedule"
+          print("schedule")
         if self.schedule == "weekly":
           if not self.changes['backup_schedule_weekday'] == self.weekly_combobox.get_active():
             changes = True
-            print "weekday"
+            print("weekday")
         elif self.schedule == "monthly":
           if not self.changes['backup_schedule_day'] == self.monthly_combobox.get_active_text():
             changes = True
-            print "day"
+            print("day")
         if not self.schedule == "disabled":        
           if not self.changes['backup_schedule_hour'] == self.schedule_hour_combobox.get_active_text():
-            print "hour"
+            print("hour")
             changes = True
           if not self.changes['backup_schedule_minute'] == self.schedule_minute_combobox.get_active_text():
-            print "minute"
+            print("minute")
             changes = True
         if changes == True:
           self._markReconfigureUser('Update Configuration', True)
@@ -281,7 +280,7 @@ class BareConsolePlugin(MCCPlugin):
     def update_status_thread(self):
 #        while True:
         self.update_status_window()
-        print "update"
+        print("update")
         time.sleep(1)
         return True
 
@@ -301,7 +300,7 @@ class BareConsolePlugin(MCCPlugin):
               lastseen_lines += lastseen+'\n'
               status_lines += status+'\n'
           except:
-            print "Invalid line in client.db"
+            print("Invalid line in client.db")
         f.close
         self.status_host_buffer.set_text(host_lines)
         self.status_lastbackup_buffer.set_text(lastbackup_lines)
@@ -319,7 +318,7 @@ class BareConsolePlugin(MCCPlugin):
         time.sleep(2)
         for item in reconfigure:
             if item == "Update Configuration":
-              newconfig = ConfigParser.ConfigParser()
+              newconfig = configparser.ConfigParser()
               self.emit_progress("Reading configuration file", 30)
               try:
                 newconfig.read(CONFIGFILE)
@@ -364,7 +363,7 @@ class BareConsolePlugin(MCCPlugin):
               h.update(f.read())
               hsh = h.hexdigest()
               f.close()
-              hashconfig = ConfigParser.ConfigParser()
+              hashconfig = configparser.ConfigParser()
               hashconfig.read(CONFIGFILE)
               hashconfig.set("General", "checksum", hsh)
               self.emit_progress("Saving configuration file", 80)
